var structcs__inflow__sem__t =
[
    [ "energy", "structcs__inflow__sem__t.html#ab603e1d5c93f641c4db2748f90feaf62", null ],
    [ "n_structures", "structcs__inflow__sem__t.html#a6f582811d8d6a675f6708660f8e2a366", null ],
    [ "position", "structcs__inflow__sem__t.html#af37da5ac7b4d1f35edabebbab77e186e", null ]
];